@@ -3,7 +3,7 @@ use warnings;
 
 package App::gcal;
 {
-  $App::gcal::VERSION = '1.113220';
+  $App::gcal::VERSION = '1.113460';
 }
 
 use Class::ReturnValue;
@@ -13,6 +13,7 @@ use Data::ICal;
 
 our $gcal;
 
+
 # entry point
 sub run {
     my (@args) = @_;
@@ -111,8 +112,6 @@ sub _create_new_gcal_event {
     my $event = Net::Google::Calendar::Entry->new();
 
     $event->title( $entry->property('summary')->[0]->value );
-    $event->content( $entry->property('description')->[0]->value );
-    $event->location( $entry->property('location')->[0]->value );
     $event->when(
         DateTime::Format::ICal->parse_datetime(
             $entry->property('dtstart')->[0]->value
@@ -123,6 +122,14 @@ sub _create_new_gcal_event {
     );
     $event->status('confirmed');
 
+    # optional
+    if ( $entry->property('description') ) {
+        $event->content( $entry->property('description')->[0]->value );
+    }
+    if ( $entry->property('location') ) {
+        $event->location( $entry->property('location')->[0]->value );
+    }
+
     return $event;
 }
 
@@ -147,7 +154,7 @@ App::gcal - Command Line Interface interface to Google Calendar.
 
 =head1 VERSION
 
-version 1.113220
+version 1.113460
 
 =head1 SYNOPSIS
 
@@ -170,7 +177,7 @@ You can also pass one or more strings to the C<gcal> command, which will attempt
 =head1 USAGE
 
   gcal --help
-  
+
   gcal [events.ical, 'tomorrow at noon. Lunch with Bob', ...]
 
 =head1 AUTHOR
